@@ -1,10 +1,8 @@
 #!/usr/bin/env python
 # coding: utf-8
 #%%
-from dpdispatcher import dp_cloud_server
 from dpdispatcher.base_context import BaseContext
-import os, sys, paramiko, json, uuid, tarfile, time, stat, shutil
-from glob import glob
+import os
 # from dpdispatcher import dlog
 # from dpdispatcher.submission import Machine
 from .dpcloudserver import api
@@ -23,6 +21,8 @@ class DpCloudServerContext(BaseContext):
         local_root,
         remote_root=None,
         remote_profile={},
+        *args,
+        **kwargs,
     ):
         self.temp_local_root = os.path.abspath(local_root)
         self.remote_profile = remote_profile
