@@ -1,9 +1,12 @@
 
 import os
 import json
-import oss2
-from oss2 import SizedFileAdapter, determine_part_size
-from oss2.models import PartInfo
+try:
+    import oss2
+    from oss2 import SizedFileAdapter, determine_part_size
+    from oss2.models import PartInfo
+except ImportError:
+    pass
 import requests
 from urllib.parse import urljoin
 from dpdispatcher import dlog
@@ -90,9 +93,10 @@ def upload(oss_task_zip, zip_task_file, endpoint, bucket_name):
             parts.append(PartInfo(part_number, result.etag))
             offset += num_to_upload
             part_number += 1
+    # result = bucket.complete_multipart_upload(oss_task_zip, upload_id, parts)
     result = bucket.complete_multipart_upload(oss_task_zip, upload_id, parts)
     # print('debug:upload_result:', result, dir())
-    return True
+    return result
 
 
 def job_create(job_type, oss_path, input_data):
