@@ -1,4 +1,3 @@
-import os,sys,time,random,uuid
 import psutil
 
 from dpdispatcher.JobStatus import JobStatus
@@ -23,10 +22,10 @@ class Shell(Machine):
         script_file_name = job.script_file_name
         job_id_name = job.job_hash + '_job_id'
         self.context.write_file(fname=script_file_name, write_str=script_str)
-        proc = self.context.call('cd %s && exec bash %s' % (self.context.remote_root, script_file_name))
-
+        proc = self.context.call('cd %s && exec bash %s &' % (self.context.remote_root, script_file_name) )
+        proc.wait()
+        # proc.kill()
         job_id = int(proc.pid)
-        # print('shell.do_submit.job_id', job_id)
         self.context.write_file(job_id_name, str(job_id))
         return job_id
 
@@ -48,7 +47,7 @@ class Shell(Machine):
     def check_status(self, job):
         job_id = job.job_id
         # print('shell.check_status.job_id', job_id)
-        job_state = JobStatus.unknown
+        # job_state = JobStatus.unknown
         if job_id == "" :
             return JobStatus.unsubmitted
 
@@ -61,7 +60,7 @@ class Shell(Machine):
             return JobStatus.running
         else:
             return JobStatus.terminated
-        return job_state
+        # return job_state
     
     # def check_status(self, job):
     #     job_id = job.job_id
@@ -74,37 +73,6 @@ class Shell(Machine):
     #             return True
     #     return False
 
-    def check_status_(self, job):
-        job_id = job.job_id
-        if job_id == "" :
-            return JobStatus.unsubmitted
-        ret, stdin, stdout, stderr\
-            = self.context.block_call ("qstat -x " + job_id)
-        err_str = stderr.read().decode('utf-8')
-        if (ret != 0) :
-            if str("qstat: Unknown Job Id") in err_str :
-                if self.check_finish_tag() :
-                    return JobStatus.finished
-                else :
-                    return JobStatus.terminated
-            else :
-                raise RuntimeError ("status command qstat fails to execute. erro info: %s return code %d"
-                                    % (err_str, ret))
-        status_line = stdout.read().decode('utf-8').split ('\n')[-2]
-        status_word = status_line.split ()[-2]        
-        # dlog.info (status_word)
-        if status_word in ["Q","H"] :
-            return JobStatus.waiting
-        elif    status_word in ["R"] :
-            return JobStatus.running
-        elif    status_word in ["C", "E", "K", "F"] :
-            if self.check_finish_tag(job) :
-                return JobStatus.finished
-            else :
-                return JobStatus.terminated
-        else :
-            return JobStatus.unknown
-
     def check_finish_tag(self, job):
         job_tag_finished = job.job_hash + '_job_tag_finished'
         # print('job finished: ',job.job_id, job_tag_finished)
