@@ -99,7 +99,9 @@ class SSHSession (object):
         self.ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy)
         self.ssh.connect(hostname=self.hostname, port=self.port,
                         username=self.username, password=self.password,
-                        key_filename=self.key_filename, timeout=self.timeout,passphrase=self.passphrase)
+                        key_filename=self.key_filename, timeout=self.timeout,passphrase=self.passphrase,
+                        compress=True,
+                        )
         assert(self.ssh.get_transport().is_active())
         transport = self.ssh.get_transport()
         transport.set_keepalive(60)
@@ -259,13 +261,14 @@ class SSHContext(BaseContext):
                submission,
                # local_up_files,
                dereference = True) :
-        self.ssh_session.ensure_alive()
         cwd = os.getcwd()
         os.chdir(self.local_root) 
         file_list = []
+        directory_list = []
         
       #   for ii in job_dirs :
-        for task in submission.belonging_tasks :
+        for task in submission.belonging_tasks:
+            directory_list.append(task.task_work_path)
             for jj in task.forward_files :
                 # file_list.append(os.path.join(ii, jj))        
                 file_list.append(os.path.join(task.task_work_path, jj))        
@@ -273,7 +276,7 @@ class SSHContext(BaseContext):
         #     file_list.append(ii)
         file_list.extend(submission.forward_common_files)
 
-        self._put_files(file_list, dereference = dereference)
+        self._put_files(file_list, dereference = dereference, directories=directory_list)
         os.chdir(cwd)
 
     def download(self, 
@@ -401,7 +404,23 @@ class SSHContext(BaseContext):
 
     def _put_files(self,
                    files,
-                   dereference = True) :
+                   dereference = True,
+                   directories = None,
+                   ) :
+        """Upload files to server.
+
+        Parameters
+        ----------
+        files: list
+            uploaded files
+        dereference: bool, default: True
+            If dereference is False, add symbolic and hard links to the archive.
+            If it is True, add the content of the target files to the archive.
+            This has no effect on systems that do not support symbolic links.
+        directories: list, default: None
+            uploaded directories non-recursively. Use `files` for uploading
+            recursively
+        """
         of = self.submission.submission_hash + '.tgz'
         # local tar
         cwd = os.getcwd()
@@ -411,8 +430,12 @@ class SSHContext(BaseContext):
         with tarfile.open(of, "w:gz", dereference = dereference) as tar:
             for ii in files :
                 tar.add(ii)
+            if directories is not None:
+                for ii in directories:
+                    tar.add(ii, recursive=False)
         os.chdir(cwd)
 
+        self.ssh_session.ensure_alive()
         try:
             self.sftp.mkdir(self.remote_root)
         except OSError: 
